@@ -1,4 +1,4 @@
-__all__ = ('NewUserActionPoint', 'FirstLoanActionPoint')
+__all__ = ('ActionDescriptionPoint', 'NewUserActionPoint', 'FirstLoanActionPoint')
 
 from expressmoney.api import *
 
@@ -6,6 +6,23 @@ SERVICE = 'partners'
 APP = 'actions'
 
 
+class ActionDescriptionReadContract(Contract):
+    NEW_USER = 'NEW_USER'
+    FIRST_LOAN = 'FIRST_LOAN'
+    NAME_CHOICES = (
+        (NEW_USER, NEW_USER),
+        (FIRST_LOAN, FIRST_LOAN),
+    )
+    RU = 'RU'
+    COUNTRY_CHOICES = (
+        (RU, RU),
+    )
+    updated = serializers.DateTimeField()
+    name = serializers.ChoiceField(choices=NAME_CHOICES)
+    country = serializers.ChoiceField(choices=COUNTRY_CHOICES)
+    reward = serializers.DecimalField(max_digits=16, decimal_places=0)
+
+
 class NewUserActionCreateContract(Contract):
     pass
 
@@ -24,6 +41,12 @@ class FirstLoanActionReadContract(NewUserActionReadContract):
     pass
 
 
+class ActionDescriptionID(ID):
+    _service = SERVICE
+    _app = APP
+    _view_set = 'action_description'
+
+
 class NewUserActionID(ID):
     _service = SERVICE
     _app = APP
@@ -36,6 +59,12 @@ class FirstLoanActionID(ID):
     _view_set = 'first_loan_action'
 
 
+class ActionDescriptionPoint(ListPointMixin, ContractPoint):
+    _point_id = ActionDescriptionID()
+    _read_contract = ActionDescriptionReadContract
+    _sort_by = 'updated'
+
+
 class NewUserActionPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _point_id = NewUserActionID()
     _create_contract = NewUserActionCreateContract
